###############
Getting started
###############

Installation
============

Install pygaia as follows:

From PyPI

.. code-block:: console
    
    > pip install pygaia

From source

.. code-block:: console
    
    > git clone https://github.com/agabrown/PyGaia.git
    > cd PyGaia
    > python -m pip install .

Dependencies
------------

The following python packages are required:

* `numpy <http://www.numpy.org/>`_
* `scipy <https://scipy.org/>`_
* `pandas <https://pandas.pydata.org/>`_
* `UltraJSON <https://github.com/ultrajson/ultrajson>`_

For the plotting tools the following packages are required:

* `matplotlib <https://matplotlib.org/>`_